/***************************************************************************
 *   Copyright (C) 2009 - 2010 by Dr. Oliver Heidbüchel                    *
 *                         (post@oliver-heidbuechel.de)                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#include "mainwindow.h"
#include "sparqlquerytab.h"
#include "statementwidget.h"

#include <nepomuk/resourcemanager.h>
 
#include <KAction>
#include <KActionCollection>
#include <KApplication>
#include <KLocale>
#include <KStandardAction>
#include <KTabWidget>

#include <QSplitter>

 
MainWindow::MainWindow(QWidget *parent)
  : KXmlGuiWindow(parent)
{
  // Model
  model = Nepomuk::ResourceManager::instance()->mainModel();

  // Splitter
  QSplitter * container = new QSplitter(this);
  
  // left side
  statement = new StatementWidget(model, this);
  container->addWidget(statement);
  
  // right side
  tabCounter = 0;
  querytabs = new KTabWidget(this);
  querytabs->setMovable(true);
  querytabs->setTabsClosable(true);
  connect(querytabs, SIGNAL(tabCloseRequested(int)), this, SLOT(removeTab(int)));
  newSparqlQueryTab();
  container->addWidget(querytabs);
  
  // finish
  setCentralWidget(container);
  createMenu();
  setupGUI();
}

void MainWindow::createMenu()
{
   KStandardAction::quit(kapp, SLOT(quit()), actionCollection());

   KAction* newSparqlQueryTabAction = new KAction(this);
   newSparqlQueryTabAction->setText(i18n("New &amp;Tab"));
   newSparqlQueryTabAction->setIcon(KIcon("tab-new"));
   newSparqlQueryTabAction->setShortcut(Qt::CTRL+Qt::Key_T);
   actionCollection()->addAction("newsparqlquerytab", newSparqlQueryTabAction);
   connect(newSparqlQueryTabAction, SIGNAL(triggered(bool)), this, SLOT(newSparqlQueryTab()));
}

void MainWindow::newSparqlQueryTab()
{
  newSparqlQueryTab("");
}

void MainWindow::newSparqlQueryTab(const QString &query)
{
  tabCounter++;
  SparqlQueryTab *qt = new SparqlQueryTab(model, this);
  querytabs->addTab(qt, KIcon("nepomuk"), i18n("Query %1", tabCounter));
  querytabs->setCurrentIndex(querytabs->count() - 1);
  
  connect(qt, SIGNAL(asSubjectSelected(const QString &)), statement, SLOT(setSubject(const QString &)));
  connect(qt, SIGNAL(asPredicateSelected(const QString &)), statement, SLOT(setPredicate(const QString &)));
  connect(qt, SIGNAL(asObjectSelected(const QString &)), statement, SLOT(setObject(const QString &)));
  connect(qt, SIGNAL(asContextSelected(const QString &)), statement, SLOT(setContext(const QString &)));
  connect(qt, SIGNAL(newQueryCommisioned(const QString &)), this, SLOT(newSparqlQueryTab(const QString &)));

  if (query.trimmed() != ""){
    qt->executeQuery(query);
  }
}

void MainWindow::removeTab(int index)
{
  querytabs->removeTab(index);
}


